﻿using System;
using System.Drawing;
using System.Drawing.Drawing2D;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                false,                          // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.OrdersTableAdapter().GetData();

            this.gridView.BestFitColumns();

            this.gridView.CustomDrawCell += gridView_CustomDrawCell;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 셀 커스텀 그리기 - gridView_CustomDrawCell(sender, e)

        /// <summary>
        /// 그리드 뷰 셀 커스텀 그리기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomDrawCell(object sender, RowCellCustomDrawEventArgs e)
        {
            if(e.Column.FieldName != "OrderDate")
            {
                return;
            }

            DateTime orderDate = (DateTime)e.CellValue;

            if(orderDate > DateTime.Today)
            {
                return;
            }

            string displayText;

            if(orderDate < DateTime.Today)
            {
                displayText = ((TimeSpan)(DateTime.Today - orderDate)).Days.ToString() + " 일전";
            }
            else
            {
                displayText = e.DisplayText;
            }

            LinearGradientBrush brush = new LinearGradientBrush
            (
                e.Bounds,
                Color.Pink,
                Color.White,
                LinearGradientMode.ForwardDiagonal
            );

            using(brush)
            {
                e.Cache.FillRectangle(brush, e.Bounds);
            }

            e.Cache.DrawString(displayText, e.Appearance.Font, Brushes.Black, e.Bounds);

            e.Handled = true;
        }

        #endregion
    }
}